<?php
/**
 * DZF
 *
 * LICENSE: Redistribution and use in source and binary forms, with or without
 * modifications, are not permitted.
 *
 * @copyright Deubert IT-Solutions © 2012-2014 All rights reserved
 * @package DZF
 */

#namespace DeubertIt;

/**
 * @author Karsten Deubert <info@deubert.it>
 */
class DZF_Controller_Action_Helper_DataSender extends \Zend_Controller_Action_Helper_Abstract
{
    /**
     * Send the specified data as the PHP file to the browser.
     *
     * @param   array           $data
     * @param   string          $dataName       (optional)
     */
    public function exportAsPhp($data, $dataName = null)
    {
        $now = time();

        $auth = \Zend_Auth::getInstance();
        $identity = $auth->getIdentity();

        $fileContent = "<?php\n\n";
        $fileContent .= "/*\n";
        $fileContent .= ' * Exported by: ' . $identity['id'] . ' (' . $identity['email'] . ")\n";
        $fileContent .= ' * Date: ' . date('d.m.Y H:i:s', $now) . "\n";
        $fileContent .= ' * Application: ' . APPLICATION_NAME . "\n";
        $fileContent .= ' * Environment: ' . APPLICATION_ENV . "\n";
        $fileContent .= ' * Name: ' . $dataName . "\n";
        $fileContent .= " */\n\n";
        $fileContent .= '$data = ' . var_export($data, true) . ';';

        $fileName = 'debugexport_' . date('Y-m-d_H-i-s', $now);

        if ($dataName)
        {
            $fileName .= '-' . $dataName;
        }

        $fileName .= '.php';

        $this->getActionController()->getHelper('Layout')->disableLayout();
        $this->getActionController()->getHelper('ViewRenderer')->setNoRender();

        $disposition = 'attachment';
        $mimeType = 'application/octet-stream';

        $this->getResponse()->clearAllHeaders();
        $this->getResponse()->setHeader('Pragma', 'public', true);
        $this->getResponse()->setHeader('Expires','0', true);
        $this->getResponse()->setHeader('Cache-Control', 'private', true);
        $this->getResponse()->setHeader('Content-Type', $mimeType, true);
        $this->getResponse()->setHeader('Content-Disposition', "$disposition; filename=\"{$fileName}\"", true);
        $this->getResponse()->setHeader('Content-Length', strlen($fileContent), true);
        $this->getResponse()->setHeader('Connection', 'close');
        $this->getResponse()->setBody($fileContent);
    }

    /**
     * Send the specified data as the ZIP file to the browser.
     *
     * Data format:
     *
     * array(
     *     file_name_in_zip1 => file_content1,
     *     [file_name_in_zip2 => file_content2,]
     *     ...
     * )
     *
     * @param   array           $filesData
     * @param   string          $fileName
     */
    public function exportAsZip($filesData, $fileName)
    {
        $filePath = TEMP_PATH . '/' . $fileName;
        $this->_packDataToZip($filesData, $filePath);

        $this->getActionController()->getHelper('Layout')->disableLayout();
        $this->getActionController()->getHelper('ViewRenderer')->setNoRender();

        $disposition = 'attachment';
        $mimeType = 'application/zip';

        $fileContent = file_get_contents($filePath);

        $this->getResponse()->clearAllHeaders();
        $this->getResponse()->setHeader('Pragma', 'public', true);
        $this->getResponse()->setHeader('Expires','0', true);
        $this->getResponse()->setHeader('Cache-Control', 'private', true);
        $this->getResponse()->setHeader('Content-Type', $mimeType, true);
        $this->getResponse()->setHeader('Content-Disposition', "$disposition; filename=\"{$fileName}\"", true);
        $this->getResponse()->setHeader('Content-Length', strlen($fileContent), true);
        $this->getResponse()->setHeader('Connection', 'close');
        $this->getResponse()->setBody($fileContent);
    }

    /**
     * @param   array           $filesData
     * @param   string          $zipFilename
     * @throws  \Exception
     */
    protected function _packDataToZip($filesData, $zipFilename)
    {
        unlink($zipFilename);

        $zip = new \ZipArchive();

        if (($code = $zip->open($zipFilename, \ZipArchive::CREATE)) !== true)
        {
            throw new DZF_Exception('Can not create archive "' . $zipFilename . '"; code ' . $code);
        }

        foreach ($filesData as $filename => $content)
        {
            if (strpos($filename, '/') !== false)
            {
                // will fail on multiply dir adding, so skip errors here
                $zip->addEmptyDir(dirname($filename));
            }

            if (strpos($filename, 'files/') === 0)
            {
                $fullpath = $content;
                $localpath = $filename;

                if (!$zip->addFile($fullpath, $localpath))
                {
                    throw new DZF_Exception('Zip failure: ' . $zip->getStatusString());
                }
            }
            else
            {
                if (!$zip->addFromString($filename, $content))
                {
                    throw new DZF_Exception('Zip failure: ' . $zip->getStatusString());
                }
            }
        }

        if (!$zip->close())
        {
            throw new DZF_Exception('Zip failure: ' . $zip->getStatusString());
        }
    }
}
