<?php

class DZF_Doctrine_HelperTests extends DZF_Helpers_TestCaseBase
{
    public function testGetModelColumnData()
    {
        $model = 'User';
        $expectedColumns = array(
            'id' => array(
                'type' => 'integer',
                'length' => 8,
                'primary' => 1,
                'autoincrement' => 1
            ),
            'first_name' => array(
                'type' => 'string',
                'length' => 255
            ),
            'last_name' => array(
                'type' => 'string',
                'length' => 255
            ),
            'username' => array(
                'type' => 'string',
                'length' => 255
            ),
            'password' => array(
                'type' => 'string',
                'length' => 255
            ),
            'type' => array(
                'type' => 'string',
                'length' => 255
            ),
            'is_active' => array(
                'type' => 'integer',
                'length' => 1,
                'default' => 1
            ),
            'is_super_admin' => array(
                'type' => 'integer',
                'length' => 1,
                'default' => 0
            ),
            'created_at' => array(
                'type' => 'timestamp',
                'notnull' => 1,
                'length' => 25
            )
        );

        $columns = DZF_Doctrine_Helper::getModelColumnData($model, 'id');
        $this->assertEquals($expectedColumns['id'], $columns);

        $columns = DZF_Doctrine_Helper::getModelColumnData($model, 'first_name');
        $this->assertEquals($expectedColumns['first_name'], $columns);

        $columns = DZF_Doctrine_Helper::getModelColumnData($model, 'last_name');
        $this->assertEquals($expectedColumns['last_name'], $columns);

        $columns = DZF_Doctrine_Helper::getModelColumnData($model, 'username');
        $this->assertEquals($expectedColumns['username'], $columns);

        $columns = DZF_Doctrine_Helper::getModelColumnData($model, 'password');
        $this->assertEquals($expectedColumns['password'], $columns);

        $columns = DZF_Doctrine_Helper::getModelColumnData($model, 'type');
        $this->assertEquals($expectedColumns['type'], $columns);

        $columns = DZF_Doctrine_Helper::getModelColumnData($model, 'is_active');
        $this->assertEquals($expectedColumns['is_active'], $columns);

        $columns = DZF_Doctrine_Helper::getModelColumnData($model, 'is_super_admin');
        $this->assertEquals($expectedColumns['is_super_admin'], $columns);

        $columns = DZF_Doctrine_Helper::getModelColumnData($model, 'created_at');
        $this->assertEquals($expectedColumns['created_at'], $columns);
    }

    public function testGetLayoutConfig()
    {
        $modelNames = array('User', 'Table2');
        $expectedLayoutConfig = array(
            'User' => array(),
            'Table2' => array()
        );

        $layoutConfig = DZF_Doctrine_Helper::getLayoutConfig($modelNames);
        $this->assertEquals($expectedLayoutConfig, $layoutConfig);
    }

    public function testGetModelPrimaryKeys()
    {
        $model = 'User';
        $expectedColumns = array('id');

        $columns = DZF_Doctrine_Helper::getModelPrimaryKeys($model);
        $this->assertEquals($expectedColumns, $columns);
    }

    public function testGetModelRelations()
    {
        $model = 'Table2';

        $expectedAlias = 'User';
        $expectedForeign = 'id';
        $expectedLocal = 'user_id';

        /** @var \Doctrine_Relation $relations */
        $relations = DZF_Doctrine_Helper::getModelRelations($model)['User'];
        $this->assertEquals($expectedAlias, $relations->getAlias());
        $this->assertEquals($expectedForeign, $relations->getForeign());
        $this->assertEquals($expectedLocal, $relations->getLocal());
    }

    public function testGetObjectTypeFromRelationName()
    {
        $expectedModelName = 'User';

        $newModelName = DZF_Doctrine_Helper::getObjectTypeFromRelationName('User', 'Table2', 'User');
        $this->assertEquals($expectedModelName, $newModelName);
    }

    public function testUpdateFromPostValues()
    {
        $model = 'User';
        /** @var \Doctrine_Record $dummy */
        $dummy = new $model;

        $formData = array(
            'User--id' => 1,
            'User--first_name' => 'Test first_name',
            'User--last_name' => 'Test last_name',
            'User--username' => 'Test username',
            'User--password' => 'Test password',
            'User--type' => 'Test type',
            'User--is_active' => 1,
            'User--is_super_admin' => 1,
            'User--created_at' => '2009-06-04 22:00:00',
            'User--updated_at' => '20010-06-04 22:00:00'
        );

        DZF_Doctrine_Helper::updateFromPostValues($dummy, $formData);

        $this->assertEquals($formData['User--id'], $dummy->get('id'));
        $this->assertEquals($formData['User--first_name'], $dummy->get('first_name'));
        $this->assertEquals($formData['User--last_name'], $dummy->get('last_name'));
        $this->assertEquals($formData['User--username'], $dummy->get('username'));
        $this->assertEquals($formData['User--password'], $dummy->get('password'));
        $this->assertEquals($formData['User--type'], $dummy->get('type'));
        $this->assertEquals($formData['User--is_active'], $dummy->get('is_active'));
        $this->assertEquals($formData['User--is_super_admin'], $dummy->get('is_super_admin'));
        $this->assertEquals($formData['User--created_at'], $dummy->get('created_at'));
        $this->assertEquals($formData['User--updated_at'], $dummy->get('updated_at'));
    }
}
