<?php


class DZF_Http_ClientTests extends DZF_Helpers_TestCaseBase
{
    const HTTP_OK = 200;
    const HTTP_NOT_FOUND = 404;

    public function testGETRequest()
    {
        $client = new DZF_Http_Client();
        $testUrl = 'http://httpbin.org/get';
        $client->setUri($testUrl);

        $response = $client->request('GET');
        $this->assertEquals(self::HTTP_OK, $response->getStatus());
    }

    public function testPOSTRequest()
    {
        $client = new DZF_Http_Client();
        $testUrl = 'http://httpbin.org/post';
        $client->setUri($testUrl);

        $response = $client->request('POST');
        $this->assertEquals(self::HTTP_OK, $response->getStatus());
    }

    public function testPUTRequest()
    {
        $client = new DZF_Http_Client();
        $testUrl = 'http://httpbin.org/put';
        $client->setUri($testUrl);

        $response = $client->request('PUT');
        $this->assertEquals(self::HTTP_OK, $response->getStatus());
    }

    public function testDELETERequest()
    {
        $client = new DZF_Http_Client();
        $testUrl = 'http://httpbin.org/delete';
        $client->setUri($testUrl);

        $response = $client->request('DELETE');
        $this->assertEquals(self::HTTP_OK, $response->getStatus());
    }

    public function testPATCHRequest()
    {
        $client = new DZF_Http_Client();
        $testUrl = 'http://httpbin.org/patch';
        $client->setUri($testUrl);

        $response = $client->request('PATCH');
        $this->assertEquals(self::HTTP_OK, $response->getStatus());
    }

    public function testNotFoundRequest()
    {
        $client = new DZF_Http_Client();
        $testUrl = 'http://httpbin.org/notFound';
        $client->setUri($testUrl);

        $response = $client->request('PATCH');
        $this->assertEquals(self::HTTP_NOT_FOUND, $response->getStatus());
    }

    /**
     * @expectedException Zend_Http_Client_Exception
     * @expectedExceptionMessage No valid URI has been passed to the client
     */
    public function testRequestException()
    {
        $client = new DZF_Http_Client();
        $client->request('PATCH');
    }

    public function testSetFullDebugLoggingActive()
    {
        $client = new DZF_Http_Client();
        $client::setFullDebugLoggingActive(true);
    }

    public function testFullDebugLog()
    {
        $client = new DZF_Http_Client();
        $testUrl = 'http://httpbin.org/get';
        $client->setUri($testUrl);
        $client::$fullDebugLoggingCustomPath = __DIR__ . '/../../Helpers/temp';

        $now = time();

        $logPath = !is_null($client::$fullDebugLoggingCustomPath)
            ? $client::$fullDebugLoggingCustomPath
            : LOG_PATH.'/dzf-http-debuglogs';

        $hh = date('H', $now);
        $path = $logPath.'/'.date('Y-m-d', $now).'/'.$hh.'/';

        $response = new Zend_Http_Response(self::HTTP_OK, array());
        $_SESSION = 'Session';

        $client->fullDebugLog($response, 'GET');

        $match = [];
        $allFiles = scandir($path);
        foreach ($allFiles as $file) {
            if (preg_match('/.*_default.php/i', $file, $match)) {
                $filePath = $path.$match[0];
                break;
            }
        }

        $data = file_get_contents($filePath);

        $this->assertNotNull($data);

        unlink($filePath);
    }

    public function testFullDebugExceptionLog()
    {
        $client = new DZF_Http_Client();
        $testUrl = 'http://httpbin.org/get';
        $client->setUri($testUrl);
        $client::$fullDebugLoggingCustomPath = __DIR__ . '/../../Helpers/temp';

        $now = time();

        $logPath = !is_null($client::$fullDebugLoggingCustomPath)
            ? $client::$fullDebugLoggingCustomPath
            : LOG_PATH.'/dzf-http-debuglogs';

        $hh = date('H', $now);
        $path = $logPath.'/'.date('Y-m-d', $now).'/'.$hh.'/';

        $response = new Zend_Http_Response(self::HTTP_OK, array());
        $_SESSION = 'Session';

        $client->fullDebugExceptionLog($response, 'GET');

        $match = [];
        $allFiles = scandir($path);
        foreach ($allFiles as $file) {
            if (preg_match('/.*_exception.php/i', $file, $match)) {
                $filePath = $path.$match[0];
                break;
            }
        }

        $data = file_get_contents($filePath);

        $this->assertNotNull($data);

        unlink($filePath);
    }

    public function testSetFullDebugLoggingCustomPath()
    {
        $client = new DZF_Http_Client();
        $client::setFullDebugLoggingCustomPath('test/path');
    }
}
