<?php

class DFZ_Log_Writer_DoctrineTests extends DZF_Helpers_TestCaseBase
{
    public function testFlush()
    {
        $event = array(
            'message' => 'This is test message',
            'priority' => 1,
            'timestamp' => '2010-06-04 00:00:00',
            'info' => 'DFZ/Log/Writer'
        );

        $doctrineLog = new DZF_Log_Writer_Doctrine();
        $doctrineLog->write($event);
        $doctrineLog->flush();
        $lastInsertId = self::$connection->lastInsertId();

        $expectedData = array(
            'id' => $lastInsertId,
            'timestamp' => '2010-06-04 00:00:00',
            'message' => 'This is test message',
            'namespace' => 'DFZ/Log/Writer',
            'priority' => 1
        );

        /** @var DzfLogs $item */
        $item = self::$connection->getTable('DzfLogs')->findOneById($lastInsertId);

        $this->assertEquals($expectedData, $item->getData());
    }

    public function testConstructor()
    {
        $doctrineLog = new DZF_Log_Writer_Doctrine('DefaultNamespace');

        $this->assertNotNull($doctrineLog);
    }

    public function testSetNamespace()
    {
        $doctrineLog = new DZF_Log_Writer_Doctrine('DefaultNamespace');
        $doctrineLog->setNamespace('NewNamespace');

        $this->assertNotNull($doctrineLog);
    }

    public function testSetBufferedMode()
    {
        $doctrineLog = new DZF_Log_Writer_Doctrine('DefaultNamespace');
        $doctrineLog->setBufferedMode(false);

        $this->assertNotNull($doctrineLog);
    }

    public function testShutdown()
    {
        $doctrineLog = new DZF_Log_Writer_Doctrine('DefaultNamespace');
        $doctrineLog->shutdown();

        $this->assertNotNull($doctrineLog);
    }

    public function testWriteBufferTrue()
    {
        $event = array(
            'message' => 'This is test message',
            'priority' => 1,
            'timestamp' => '2010-06-04 00:00:00',
            'info' => 'DFZ/Log/Writer'
        );

        $doctrineLog = new DZF_Log_Writer_Doctrine();
        $doctrineLog->setBufferedMode(1);
        $doctrineLog->write($event);
        $doctrineLog->flush();
        $lastInsertId = self::$connection->lastInsertId();

        $expectedData = array(
            'id' => $lastInsertId,
            'timestamp' => '2010-06-04 00:00:00',
            'message' => 'This is test message',
            'namespace' => 'DFZ/Log/Writer',
            'priority' => 1
        );

        /** @var DzfLogs $item */
        $item = self::$connection->getTable('DzfLogs')->findOneById($lastInsertId);

        $this->assertEquals($expectedData, $item->getData());
    }

    /**
     * @expectedException Zend_Exception
     * @expectedExceptionMessage DZF_Log_Writer_Doctrine does not currently implement a factory
     */
    public function testFactory()
    {
        DZF_Log_Writer_Doctrine::factory(array(
            'message' => 'This is test message',
            'priority' => 1,
            'timestamp' => '2010-06-04 00:00:00',
            'info' => 'DFZ/Log/Writer'
        ));
    }
}
