<?php

require_once('vendor/diablomedia/doctrine1/lib/Doctrine.php');
require_once __DIR__ . '/../../vendor/autoload.php';
require_once('tests/TestConfiguration.php');

class DZF_Helpers_TestCaseBase extends DZF_Test_PHPUnit_TestCase
{
    /** @var Doctrine_Manager */
    protected static $manager;

    /** @var Doctrine_Connection */
    protected static $connection;

    /** @var Zend_Log */
    protected static $logger;

    /**
     * @throws Doctrine_Exception
     * @throws Doctrine_Manager_Exception
     */
    public static function setUpBeforeClass()
    {
        if (!self::$connection) {
            spl_autoload_register(array('Doctrine', 'autoload'));
            spl_autoload_register(array('Doctrine', 'modelsAutoload'));
            self::$manager = Doctrine_Manager::getInstance();

            self::$connection = Doctrine_Manager::connection("sqlite:///" . __DIR__ . "/Sqlite/DB/test.db?mode=0666", 'doctrine');
            self::$manager->setAttribute(Doctrine_Core::ATTR_MODEL_LOADING, Doctrine_Core::MODEL_LOADING_CONSERVATIVE);

            try {
                Doctrine_Core::createTablesFromModels('tests/Helpers/Sqlite/models');
            } catch (Exception $exception) {
                echo $exception->getMessage() . "\n";
            }

            Doctrine_Core::loadData('tests/Helpers/Sqlite/fixtures');

            //Register Translate
            $locale = new Zend_Locale('en');
            Zend_Registry::set('Zend_Locale', $locale);
            $translate = new Zend_Translate(array('adapter' => 'tmx',
                'content' => realpath('') . '/tests/Helpers/Files/translations.tmx',
                'locale' => $locale));
            Zend_Registry::set('Zend_Translate', $translate);

            Zend_Registry::set('domain.static', 'http:://static.domain.com');

            Zend_Registry::set('secure', 'secure');

            Zend_Registry::set('domain', 'http:://domain.com');

            self::$logger = new \Zend_Log();
            $configArray = array(
                'webhost'  => 'www.example.com',
                'database' => array(
                    'adapter' => 'pdo_mysql',
                    'params'  => array(
                        'host'     => 'db.example.com',
                        'username' => 'dbuser',
                        'password' => 'secret',
                        'dbname'   => 'mydatabase'
                    )
                ),
                'writerName' => 'Null'
            );
            self::$logger->addWriter($configArray);
            Zend_Registry::set('logger', self::$logger);
        }
    }
}
